@@ -144,16 +144,53 @@ sub build {
     };
 
     # Find, parse and merge 'config' and mode files
-    for ( 'config', $self->app->mode ) {
-        if ( my $filename = $find->($_) ) {
+    for my $name ( 'config', $self->app->mode ) {
+        if ( my $filename = $find->($name) ) {
             $process->($filename);
         }
+        else {
+            if ( $ENV{KELP_CONFIG_WARN} ) {
+                my $message =
+                  $name eq 'config'
+                  ? "Main config file not found or not readable"
+                  : "Config file for mode '$name' not found or not readable";
+                  warn $message;
+            }
+        }
+    }
+
+    # Undocumented! Add 'extra' argument to unlock these special features:
+    # 1. If the extra argument contains a HASH, it will be merged to the
+    #    configuration upon loading.
+    # 2. A new attribute '_cfg' will be registered into the app, which has
+    # three methods: merge, clear and set. Use them to merge a hash into
+    # the configuration, clear it, or set it to a new value. You can do those
+    # at any point in the life of the app.
+    #
+    if ( my $extra = delete $args{extra} ) {
+        $self->data( _merge( $self->data, $extra ) ) if ref($extra) eq 'HASH';
+        $self->register(
+
+         # A tiny object containing only merge, clear and set. Very useful when
+         # you're writing tests and need to add new config options, set the
+         # entire config hash to a new value, or clear it completely.
+            _cfg => Plack::Util::inline_object(
+                merge => sub {
+                    $self->data( _merge( $self->data, $_[0] ) );
+                },
+                clear => sub { $self->data( {} ) },
+                set   => sub { $self->data( $_[0] ) }
+            )
+        );
     }
 
-    # Register two methods: config and config_hash
     $self->register(
+
+        # Return the entire config hash
         config_hash => $self->data,
-        config      => sub {
+
+        # A wrapper arount the get method
+        config => sub {
             my ( $app, $path ) = @_;
             return $self->get($path);
         }
@@ -215,32 +252,33 @@ Kelp::Module::Config - Configuration for Kelp applications
 =head1 DESCRIPTION
 
 This is one of the two modules that are automatically loaded for each and every
-Kelp application. It reads configuration files containing Perl-style hashes,
-and merges them depending on the value of the application's C<mode> attribute.
+Kelp application. The other one is L<Kelp::Module::Routes>. It reads
+configuration files containing Perl-style hashes, and merges them depending on
+the value of the application's C<mode> attribute.
 
-The main configuration file name is C<config.pl>, and it will be searched in the
-C<conf> and C<../conf> directories. You can also set the C<KELP_CONFIG_DIR> environmental
-variable with the path to the configuration files.
+The main configuration file name is C<config.pl>, and it will be searched in
+the C<conf> and C<../conf> directories. You can also set the C<KELP_CONFIG_DIR>
+environmental variable with the path to the configuration files.
 
 This module comes with some L<default values|/DEFAULTS>, so if there are no
-configuration files found, those values will be used.
-Any values from configuration files will add to or override the default values.
+configuration files found, those values will be used.  Any values from
+configuration files will add to or override the default values.
 
 =head1 ORDER
 
-First the module will look for C<conf/config.pl>, then for C<../conf/config.pl>.
-If found, they will be parsed and merged into the default values.
-The same order applies to the I<mode> file too, so if the application
-L<mode|Kelp/mode> is I<development>, then C<conf/development.pl> and
-C<../conf/development.pl> will be looked for. If found, they will also be merged
-to the config hash.
+First the module will look for C<conf/config.pl>, then for
+C<../conf/config.pl>.  If found, they will be parsed and merged into the
+default values.  The same order applies to the I<mode> file too, so if the
+application L<mode|Kelp/mode> is I<development>, then C<conf/development.pl>
+and C<../conf/development.pl> will be looked for. If found, they will also be
+merged to the config hash.
 
 =head1 MERGING
 
 The first configuration file this module will look for is C<config.pl>. This is
-where you should keep configuration options that apply to all running environments.
-The mode-specific configuration file will be merged to this config, and it will
-take priority. Merging is done as follows:
+where you should keep configuration options that apply to all running
+environments.  The mode-specific configuration file will be merged to this
+config, and it will take priority. Merging is done as follows:
 
 =over
 
@@ -344,6 +382,23 @@ A reference to the entire configuration hash.
 
 Using this or C<config> is entirely up to the application developer.
 
+=head3 _cfg
+
+A tiny object that contains only three methods - B<merge>, B<clear> and B<set>.
+It allows you to merge values to the config hash, clear it completely or
+set it to an entirely new value. This method comes handy when writing tests.
+
+    # Somewhere in a .t file
+    my $app = MyApp->new( mode => 'test' );
+
+    my %original_config = %{ $app->config_hash };
+    $app->_cfg->merge( { middleware => ['Foo'] } );
+
+    # Now you can test with middleware Foo added to the config
+
+    # Revert to the original configuration
+    $app->_cfg->set( \%original_config );
+
 =head1 ATTRIBUTES
 
 This module implements some attributes, which can be overridden by subclasses.
@@ -463,4 +518,14 @@ use the same configuration set of files for your application and for your tests.
 Assuming the all of your test will reside in C<t/>, they should be able to load
 and find the config files at C<../conf/>.
 
+=head1 ENVIRONMENT VARIABLES
+
+=head2 KELP_CONFIG_WARN
+
+This module will not warn for missing config and mode files. It will
+silently load the default configuration hash. Set KELP_CONFIG_WARN to a
+true value to make this module warn about missing files.
+
+    $ KELP_CONFIG_WARN=1 plackup app.psgi
+
 =cut
